@@ -12,8 +12,8 @@ Jasper Bekkers
 .El
 .
 .Sh REPORTING BUGS
-.Lk https:/\&/todo.sr.ht/~nabijaczleweli/tzpfms
+.Lk https:/\&/todo.sr.ht/\(tinabijaczleweli/tzpfms
 .Pp
-.Mt ~nabijaczleweli/tzpfms@lists.sr.ht ,
+.Mt \(tinabijaczleweli/tzpfms@lists.sr.ht ,
 archived at
-.Lk https:/\&/lists.sr.ht/~nabijaczleweli/tzpfms .
+.Lk https:/\&/lists.sr.ht/\(tinabijaczleweli/tzpfms .
