@@ -8,9 +8,12 @@
 
 #include <algorithm>
 #include <inttypes.h>
+#include <iterator>
+#define OPENSSL_SUPPRESS_DEPRECATED  // SHA256_*(); supposedly replaced with EVP* but that's horseshit. we'll see how she turns out, given there's no reason given
 #include <openssl/sha.h>
 #include <optional>
 #include <time.h>
+#include <utility>
 
 
 template <class F>
